@@ -8,7 +8,6 @@
 
 import pylab
 import numpy as np
-import types
 import os
 import gzip
 import zipfile
@@ -36,7 +35,7 @@ def readyellowsubmarine(nameformat,fsns=None,dirs='.'):
         filenames=[nameformat]
     else:
         filenames=[nameformat%f for f in fsns]
-    if type(dirs)!=type([]) and type(dirs)!=type(tuple()):
+    if not(isinstance(dirs,list) or isinstance(dirs,tuple)):
         dirs=[dirs]
     datas=[]
     params=[]
@@ -228,6 +227,7 @@ def bdf2B1(bdf,doffset,steps2cm,energyreal,fsnref,thicknessref,pixelsize,mult,er
                  params['InjectionEB'],params['PixelSize'])
     write2dintfile(bdf['data']*mult/thickness,np.sqrt((bdf['error']*mult)**2+(bdf['data']*errmult)**2)/thickness,params)
     return bdf['data']*mult/thickness,np.sqrt((bdf['error']*mult)**2+(bdf['data']*errmult)**2)/thickness,params
+
 def bdf_read(filename):
     """Read bdf file (Bessy Data Format)
 
@@ -352,11 +352,11 @@ def readasa(basename,dirs=[]):
             poserror: estimated error of the position (cps)
             energyerror: estimated error of the energy (cps)
     """
-    if type(dirs)==type(''):
+    if not (isinstance(dirs,list) or isinstance(dirs,tuple)):
         dirs=[dirs]
     if len(dirs)==0:
         dirs=['.']
-    if type(basename)==type(''):
+    if not (isinstance(basename,list) or isinstance(basename,tuple)):
         basenames=[basename]
         basename_scalar=True
     else:
@@ -501,7 +501,7 @@ def readheader(filename,fsn=None,fileend=None,dirs=[],quiet=False):
                      # constant in the old program on hasjusi1, which was
                      # taken over by the measurement program, to keep
                      # compatibility with that.
-    if type(dirs)==type(''):
+    if not (isinstance(dirs,list) or isinstance(dirs,tuple)):
         dirs=[dirs]
     if len(dirs)==0:
         dirs=['.']
@@ -585,6 +585,7 @@ def readheader(filename,fsn=None,fileend=None,dirs=[],quiet=False):
         if not filefound and not quiet:
             print 'readheader: Cannot find file %s in given directories.' % name
     return headers
+
 def read2dB1data(filename,files=None,fileend=None,dirs=[],quiet=False):
     """Read 2D measurement files, along with their header data
 
@@ -670,7 +671,7 @@ def read2dB1data(filename,files=None,fileend=None,dirs=[],quiet=False):
         if not quiet:
             print 'Cannot find file %s. Make sure the path is correct.' % filename
         return None
-    if type(dirs)==type(''):
+    if not (isinstance(dirs,list) or isinstance(dirs,tuple)):
         dirs=[dirs]
     if len(dirs)==0:
         dirs=['.']
@@ -733,6 +734,7 @@ def read2dB1data(filename,files=None,fileend=None,dirs=[],quiet=False):
                     data.append(tmp2);
                     header.append(tmp1);
             return data,header
+            
 def getsamplenames(filename,files,fileend,showtitles='Gabriel',dirs=[]):
     """Prints information on the measurement files
     
@@ -749,7 +751,7 @@ def getsamplenames(filename,files,fileend,showtitles='Gabriel',dirs=[]):
     Outputs:
         None
     """
-    if type(files) is not types.ListType:
+    if not (isinstance(files,list) or isinstance(files,tuple)):
         files=[files]
     if showtitles.upper().startswith('GABRIEL'):
         print 'FSN\tTime\tEnergy\tDist\tPos\tTransm\tSum/Tot %\tT (C)\tTitle\t\t\tDate'
@@ -783,6 +785,7 @@ def getsamplenames(filename,files,fileend,showtitles='Gabriel',dirs=[]):
                                                 h['Year'],
                                                 h['Hour'],
                                                 h['Minutes'])))
+                                                
 def read2dintfile(fsns,dirs=[],norm=True,quiet=False):
     """Read corrected intensity and error matrices
     
@@ -852,7 +855,7 @@ def read2dintfile(fsns,dirs=[],norm=True,quiet=False):
                     return None
         return data
     # the core of read2dintfile
-    if type(dirs)==type(''):
+    if not (isinstance(dirs,list) or isinstance(dirs,tuple)):
         dirs=[dirs]
     if len(dirs)==0:
         dirs=['.']
@@ -865,7 +868,7 @@ def read2dintfile(fsns,dirs=[],norm=True,quiet=False):
         filefound=False
         for d in dirs:
             try: # first try to load the npz file. This is the most effective way.
-                if type(norm)==type(''):
+                if isinstance(norm,str):
                     fileprefixnorm=norm
                 elif norm:
                     fileprefixnorm='int2dnorm'
@@ -880,7 +883,7 @@ def read2dintfile(fsns,dirs=[],norm=True,quiet=False):
                     tmp=tmp0['Intensity']
                     tmp1=tmp0['Error']
                 except IOError: # if mat file is not found, try the ascii files
-                    if type(norm)==type(''):
+                    if isinstance(norm,str):
                         warnings.warn(SyntaxWarning('Loading 2D ascii files when parameter <norm> for read2dintfile() is a string.'))
                         continue # try from another directory
                     if norm:
@@ -926,7 +929,7 @@ def write2dintfile(A,Aerr,params,norm=True,filetype='npz'):
     """
     if Aerr is None:
         Aerr=np.zeros((1,1))
-    if type(norm)==type(''):
+    if isinstance(norm,str):
         fileprefix='%s%d' % (norm,params['FSN'])
     elif norm:
         fileprefix='int2dnorm%d' % params['FSN']
@@ -954,7 +957,7 @@ def readintfile(filename,dirs=[],sanitize=True,quiet=False):
     """
     fields=['q','Intensity','Error','Area','qavg','qstd']
     
-    if type(dirs)==type(''):
+    if not (isinstance(dirs,list) or isinstance(dirs,tuple)):
         dirs=[dirs]
     if len(dirs)==0:
         dirs=['.']
@@ -1027,9 +1030,9 @@ def readintnorm(fsns, filetype='intnorm',dirs=[],logfiletype='intnorm',quiet=Fal
         When loading only one fsn, the outputs will be still in lists, thus
             lists with one elements will be returned.
     """
-    if type(fsns) != types.ListType:
+    if not (isinstance(fsns,list) or isinstance(fsns,tuple)):
         fsns=[fsns];
-    if type(dirs)==type(''):
+    if not (isinstance(dirs,list) or isinstance(dirs,tuple)):
         dirs=[dirs]
     if len(dirs)==0:
         dirs=['.']
@@ -1147,12 +1150,12 @@ def readlogfile(fsn,dirs=[],norm=True,quiet=False):
         else:
             return None
     #this is the beginning of readlogfile().
-    if type(norm)==type(True):
+    if isinstance(norm,bool):
         if norm:
             norm='intnorm'
         else:
             norm='intarb'
-    if type(dirs)==type(''):
+    if not (isinstance(dirs,list) or isinstance(dirs,tuple)):
         dirs=[dirs]
     if len(dirs)==0:
         dirs=['.']
@@ -1174,7 +1177,7 @@ def readlogfile(fsn,dirs=[],norm=True,quiet=False):
                     name=getname(line);
                     for k in logfile_dict_float.keys():
                         if name==k:
-                            if type(logfile_dict_float[k]) is types.StringType:
+                            if isinstance(logfile_dict_float[k],str):
                                 param[logfile_dict_float[k]]=getvalue(line);
                             else: # type(logfile_dict_float[k]) is types.TupleType
                                 param[logfile_dict_float[k][0]]=getfirstvalue(line);
@@ -1289,9 +1292,9 @@ def readwaxscor(fsns,dirs=[]):
     Output:
         a list of scattering data dictionaries (see readintfile())
     """
-    if type(fsns)!=types.ListType:
+    if not (isinstance(fsns,list) or isinstance(fsns,tuple)):
         fsns=[fsns]
-    if type(dirs)==type(''):
+    if not (isinstance(dirs,list) or isinstance(dirs,tuple)):
         dirs=[dirs]
     if len(dirs)==0:
         dirs=['.']
@@ -1327,9 +1330,9 @@ def readenergyfio(filename,files,fileend,dirs=[]):
         samples: the sample names for each fsn
         muds: the mu*d values for each fsn
     """
-    if type(files)!=types.ListType:
+    if not (isinstance(files,list) or isinstance(files,tuple)):
         files=[files]
-    if type(dirs)==type(''):
+    if not (isinstance(dirs,list) or isinstance(dirs,tuple)):
         dirs=[dirs]
     if len(dirs)==0:
         dirs=['.']
@@ -1341,7 +1344,10 @@ def readenergyfio(filename,files,fileend,dirs=[]):
         for d in dirs:
             mud=[];
             energy=[];
-            fname='%s%s%s%05d%s' % (d,os.sep,filename,f,fileend)
+            if isinstance(f,str):
+                fname='%s%s%s%s%s' % (d,os.sep,filename,f,fileend)
+            else:
+                fname='%s%s%s%05d%s' % (d,os.sep,filename,f,fileend)
             try:
                 fid=open(fname,'r')
                 lines=fid.readlines()
@@ -1518,7 +1524,7 @@ def readxanes(filebegin,files,fileend,energymeas,energycalib,dirs=[]):
             self-describing. The last will be the FSN.
     """
     muds=[];
-    if type(files)!=types.ListType:
+    if not (isinstance(files,list) or isinstance(files,tuple)):
         files=[files]
 
     for f in files:
@@ -1555,7 +1561,7 @@ def readabt(filename,dirs='.'):
             'dataset': a structured array a la numpy, containing the same data
                 as in 'data', but in another representation.
     """
-    if type(dirs)==type(''):
+    if not (isinstance(dirs,list) or isinstance(dirs,tuple)):
         dirs=[dirs]
     if len(dirs)==0:
         dirs=['.']
@@ -1656,7 +1662,7 @@ def readmask(filename,fieldname=None,dirs='.'):
     Outputs:
         the mask in a numpy array of type np.uint8
     """
-    if type(dirs)==type(''):
+    if not (isinstance(dirs,list) or isinstance(dirs,tuple)):
         dirs=[dirs]
     f=None
     for d in dirs:
@@ -1740,7 +1746,7 @@ def writeparamfile(filename,param):
         #try if it is a float argument
         k1=[x for x in logfile_dict_float.keys() if logfile_dict_float[x]==k]
         if len(k1)>0:
-            if type(k)==type(''):
+            if isinstance(k,str):
                 k=[k,]
             k=[x for x in k if x in allkeys]
             if len(k)==0:
@@ -1755,7 +1761,7 @@ def writeparamfile(filename,param):
         #try if it is a str argument
         k1=[x for x in logfile_dict_str.keys() if logfile_dict_str[x]==k]
         if len(k1)>0:
-            if type(k)==type(''):
+            if isinstance(k,str):
                 k=[k,]
             k=[x for x in k if x in allkeys]
             if len(k)==0:
@@ -1770,7 +1776,7 @@ def writeparamfile(filename,param):
         #try if it is a bool argument
         k1=[x for x in logfile_dict_bool.keys() if logfile_dict_bool[x]==k]
         if len(k1)>0:
-            if type(k)==type(''):
+            if isinstance(k,str):
                 k=[k,]
             k=[x for x in k if x in allkeys]
             if len(k)==0:
@@ -1785,7 +1791,7 @@ def writeparamfile(filename,param):
         #try if it is a list
         k1=[x for x in logfile_dict_list.keys() if logfile_dict_list[x]==k]
         if len(k1)>0:
-            if type(k)==type(''):
+            if isinstance(k,str):
                 k=[k,]
             k=[x for x in k if x in allkeys]
             if len(k)==0:
@@ -1802,4 +1808,5 @@ def writeparamfile(filename,param):
         writekey(k)
     for k in allkeys:
         writekey(k)
-    f.close()
\ No newline at end of file
+    f.close()
+    
\ No newline at end of file
